sequencetools.is_restricted_growth_function
===========================================

.. autofunction:: abjad.tools.sequencetools.is_restricted_growth_function.is_restricted_growth_function
   :noindex:
